@@ -1,4 +1,4 @@
-# Copyright 2004-2017, Paul Johnson (paul@pjcj.net)
+# Copyright 2004-2023, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -20,7 +20,7 @@ use Devel::Cover::Dumper;
 # For comprehensive debug logging.
 use constant DEBUG => 0;
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.40'; # VERSION
 our $AUTOLOAD;
 
 sub new {
@@ -75,7 +75,7 @@ sub debuglog {
 
     local $\;
     # One log file per process, as we're potentially dumping out large amounts,
-    # and might exceed the atomic write size of the OS.
+    # and might exceed the atomic write size of the OS
     open my $fh, '>>', "$dir/$$" or confess "Can't open $dir/$$: $!";
     print $fh "----------------" . gmtime() . "----------------\n";
     print $fh ref $_ ? Dumper($_) : $_;
@@ -233,10 +233,11 @@ sub write {
     unless (mkdir $dir) {
         confess "Can't mkdir $dir: $!" unless -d $dir;
     }
+    chmod 0777, $dir if $self->{loose_perms};
     for my $file (sort keys %{$self->{f}}) {
         $self->{f}{$file}{file} = $file;
         my $digest = $self->{f}{$file}{digest};
-        $digest = $1 if defined $digest && $digest =~ /(.*)/; # ie tainting.
+        $digest = $1 if defined $digest && $digest =~ /(.*)/; # ie tainting
         unless ($digest) {
             print STDERR "Can't find digest for $file"
                 unless $Devel::Cover::Silent ||
@@ -247,7 +248,7 @@ sub write {
         }
         my $df_final = "$dir/$digest";
         my $df_temp = "$dir/.$digest.$$";
-        # TODO - determine if Structure has changed to save writing it.
+        # TODO - determine if Structure has changed to save writing it
         # my $f = $df; my $n = 1; $df = $f . "." . $n++ while -e $df;
         my $io = Devel::Cover::DB::IO->new;
         $io->write($self->{f}{$file}, $df_temp); # unless -e $df;
@@ -326,7 +327,7 @@ sub read_all {
     $dir .= "/structure";
     opendir D, $dir or return;
     for my $d (sort grep $_ !~ /\./, readdir D) {
-        $d = $1 if $d =~ /(.*)/; # Die tainting.
+        $d = $1 if $d =~ /(.*)/; # Die tainting
         $self->read($d);
     }
     closedir D or die "Can't closedir $dir: $!";
@@ -336,7 +337,7 @@ sub read_all {
 sub merge {
     my $self   = shift;
     my ($from) = @_;
-    Devel::Cover::DB::_merge_hash($self->{f}, $from->{f});
+    Devel::Cover::DB::_merge_hash($self->{f}, $from->{f}, "noadd");
 }
 
 1
@@ -349,7 +350,7 @@ Devel::Cover::DB::Structure - Internal: abstract structure of a source file
 
 =head1 VERSION
 
-version 1.25
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -370,7 +371,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2004-2017, Paul Johnson (paul@pjcj.net)
+Copyright 2004-2023, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
